==> blancoOmegatUtil-0.0.5-src.zip: src/blanco/omegat/util/task/valueobject/BlancoOmegatTranslateXliffProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.omegat.util.task.valueobject;

/**
 * NX [BlancoOmegatTranslateXliffProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoOmegatTranslateXliffProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [tmxdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMX t@Ci[ĂfBNgB
     */
    private String fTmxdir;

    /**
     * tB[h [xliffdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@Ci[fBNgBxlifffileƔrpB
     */
    private String fXliffdir;

    /**
     * tB[h [xlifffile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@CBxliffdir ƔrpB
     */
    private String fXlifffile;

    /**
     * tB[h [skipiftargetexist]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * targetɂꍇɏXLbv邩ǂB
     */
    private boolean fSkipiftargetexist = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [tmxdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMX t@Ci[ĂfBNgB
     *
     * @param argTmxdir tB[h[tmxdir]Ɋi[l
     */
    public void setTmxdir(final String argTmxdir) {
        fTmxdir = argTmxdir;
    }

    /**
     * tB[h[tmxdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMX t@Ci[ĂfBNgB
     *
     * @return tB[h[tmxdir]Ɋi[Ăl
     */
    public String getTmxdir() {
        return fTmxdir;
    }

    /**
     * tB[h [xliffdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@Ci[fBNgBxlifffileƔrpB
     *
     * @param argXliffdir tB[h[xliffdir]Ɋi[l
     */
    public void setXliffdir(final String argXliffdir) {
        fXliffdir = argXliffdir;
    }

    /**
     * tB[h[xliffdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@Ci[fBNgBxlifffileƔrpB
     *
     * @return tB[h[xliffdir]Ɋi[Ăl
     */
    public String getXliffdir() {
        return fXliffdir;
    }

    /**
     * tB[h [xlifffile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@CBxliffdir ƔrpB
     *
     * @param argXlifffile tB[h[xlifffile]Ɋi[l
     */
    public void setXlifffile(final String argXlifffile) {
        fXlifffile = argXlifffile;
    }

    /**
     * tB[h[xlifffile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@CBxliffdir ƔrpB
     *
     * @return tB[h[xlifffile]Ɋi[Ăl
     */
    public String getXlifffile() {
        return fXlifffile;
    }

    /**
     * tB[h [skipiftargetexist]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * targetɂꍇɏXLbv邩ǂB
     *
     * @param argSkipiftargetexist tB[h[skipiftargetexist]Ɋi[l
     */
    public void setSkipiftargetexist(final boolean argSkipiftargetexist) {
        fSkipiftargetexist = argSkipiftargetexist;
    }

    /**
     * tB[h[skipiftargetexist]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * targetɂꍇɏXLbv邩ǂB
     *
     * @return tB[h[skipiftargetexist]Ɋi[Ăl
     */
    public boolean getSkipiftargetexist() {
        return fSkipiftargetexist;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.omegat.util.task.valueobject.BlancoOmegatTranslateXliffProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",tmxdir=" + fTmxdir);
        buf.append(",xliffdir=" + fXliffdir);
        buf.append(",xlifffile=" + fXlifffile);
        buf.append(",skipiftargetexist=" + fSkipiftargetexist);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoOmegatUtil-0.0.9-src.zip: src/blanco/omegat/util/task/valueobject/BlancoOmegatTranslateXliffProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.omegat.util.task.valueobject;

/**
 * NX [BlancoOmegatTranslateXliffProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoOmegatTranslateXliffProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [tmxdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMX t@Ci[ĂfBNgB
     */
    private String fTmxdir;

    /**
     * tB[h [xliffdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@Ci[fBNgBxlifffileƔrpB
     */
    private String fXliffdir;

    /**
     * tB[h [xlifffile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@CBxliffdir ƔrpB
     */
    private String fXlifffile;

    /**
     * tB[h [tool-id]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [omegat]<br>
     * c[IDB
     */
    private String fToolId = "omegat";

    /**
     * tB[h [origin]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̏oB
     */
    private String fOrigin;

    /**
     * tB[h [skipiftargetexist]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * targetɂꍇɏXLbv邩ǂB
     */
    private boolean fSkipiftargetexist = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [tmxdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMX t@Ci[ĂfBNgB
     *
     * @param argTmxdir tB[h[tmxdir]Ɋi[l
     */
    public void setTmxdir(final String argTmxdir) {
        fTmxdir = argTmxdir;
    }

    /**
     * tB[h[tmxdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMX t@Ci[ĂfBNgB
     *
     * @return tB[h[tmxdir]Ɋi[Ăl
     */
    public String getTmxdir() {
        return fTmxdir;
    }

    /**
     * tB[h [xliffdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@Ci[fBNgBxlifffileƔrpB
     *
     * @param argXliffdir tB[h[xliffdir]Ɋi[l
     */
    public void setXliffdir(final String argXliffdir) {
        fXliffdir = argXliffdir;
    }

    /**
     * tB[h[xliffdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@Ci[fBNgBxlifffileƔrpB
     *
     * @return tB[h[xliffdir]Ɋi[Ăl
     */
    public String getXliffdir() {
        return fXliffdir;
    }

    /**
     * tB[h [xlifffile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@CBxliffdir ƔrpB
     *
     * @param argXlifffile tB[h[xlifffile]Ɋi[l
     */
    public void setXlifffile(final String argXlifffile) {
        fXlifffile = argXlifffile;
    }

    /**
     * tB[h[xlifffile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ́Eo͐ƂȂ OASIS XLIFF t@CBxliffdir ƔrpB
     *
     * @return tB[h[xlifffile]Ɋi[Ăl
     */
    public String getXlifffile() {
        return fXlifffile;
    }

    /**
     * tB[h [tool-id]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * c[IDB
     *
     * @param argToolId tB[h[tool-id]Ɋi[l
     */
    public void setToolId(final String argToolId) {
        fToolId = argToolId;
    }

    /**
     * tB[h[tool-id]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [omegat]<br>
     * c[IDB
     *
     * @return tB[h[tool-id]Ɋi[Ăl
     */
    public String getToolId() {
        return fToolId;
    }

    /**
     * tB[h [origin]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̏oB
     *
     * @param argOrigin tB[h[origin]Ɋi[l
     */
    public void setOrigin(final String argOrigin) {
        fOrigin = argOrigin;
    }

    /**
     * tB[h[origin]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̏oB
     *
     * @return tB[h[origin]Ɋi[Ăl
     */
    public String getOrigin() {
        return fOrigin;
    }

    /**
     * tB[h [skipiftargetexist]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * targetɂꍇɏXLbv邩ǂB
     *
     * @param argSkipiftargetexist tB[h[skipiftargetexist]Ɋi[l
     */
    public void setSkipiftargetexist(final boolean argSkipiftargetexist) {
        fSkipiftargetexist = argSkipiftargetexist;
    }

    /**
     * tB[h[skipiftargetexist]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * targetɂꍇɏXLbv邩ǂB
     *
     * @return tB[h[skipiftargetexist]Ɋi[Ăl
     */
    public boolean getSkipiftargetexist() {
        return fSkipiftargetexist;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.omegat.util.task.valueobject.BlancoOmegatTranslateXliffProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",tmxdir=" + fTmxdir);
        buf.append(",xliffdir=" + fXliffdir);
        buf.append(",xlifffile=" + fXlifffile);
        buf.append(",tool-id=" + fToolId);
        buf.append(",origin=" + fOrigin);
        buf.append(",skipiftargetexist=" + fSkipiftargetexist);
        buf.append("]");
        return buf.toString();
    }
}
